@@ -181,7 +181,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 			cairo_stroke (cr);
 		}
 
-		if (params->is_default)
+		if (params->is_default && !params->disabled)
 		{
 			CairoColor shadow = colors->spot[1];
 
@@ -271,13 +271,7 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 
-	/* Fill the background as it is initilized to base[NORMAL].
-	 * Relevant GTK+ bug: http://bugzilla.gnome.org/show_bug.cgi?id=513471 */
-	cairo_rectangle (cr, 0, 0, width, height);
-	ge_cairo_set_color (cr, &params->parentbg);
-	cairo_fill (cr);
-
-	/* Now fill the area we want to be base[NORMAL] again. */
+	/* Now fill the area we want to be base[NORMAL]. */
 	ge_cairo_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
 	ge_cairo_set_color (cr, base);
 	cairo_fill (cr);
@@ -327,12 +321,6 @@ clearlooks_gummy_draw_progressbar_trough (cairo_t                *cr,
 
 	cairo_set_line_width (cr, 1.0);
 
-	/* Fill with bg color */
-	ge_cairo_set_color (cr, &colors->bg[params->state_type]);
-
-	cairo_rectangle (cr, x, y, width, height);
-	cairo_fill (cr);
-
 	/* Create trough box */
 	ge_cairo_rounded_rectangle (cr, x+1, y+1, width-2, height-2, radius, params->corners);
 	ge_cairo_set_color (cr, &colors->shade[2]);
@@ -1393,6 +1381,13 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 	cairo_pattern_t *pt;
 	gboolean inconsistent;
 	gboolean draw_bullet = (checkbox->shadow_type == GTK_SHADOW_IN);
+	gdouble w, h, cx, cy, radius;
+
+	w = (gdouble) width;
+	h = (gdouble) height;
+	cx = width / 2.0;
+	cy = height / 2.0;
+	radius = MIN (width, height) / 2.0;
 
 	inconsistent = (checkbox->shadow_type == GTK_SHADOW_ETCHED_IN);
 	draw_bullet |= inconsistent;
@@ -1414,7 +1409,7 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 	ge_shade_color (&widget->parentbg, 0.9, &shadow);
 	ge_shade_color (&widget->parentbg, 1.1, &highlight);
 
-	pt = cairo_pattern_create_linear (0, 0, 13, 13);
+	pt = cairo_pattern_create_linear (0, 0, radius * 2.0, radius * 2.0);
 	cairo_pattern_add_color_stop_rgb (pt, 0.0, shadow.r, shadow.b, shadow.g);
 	cairo_pattern_add_color_stop_rgba (pt, 0.5, shadow.r, shadow.b, shadow.g, 0.5);
 	cairo_pattern_add_color_stop_rgba (pt, 0.5, highlight.r, highlight.g, highlight.b, 0.5);
@@ -1422,15 +1417,15 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 
 	cairo_translate (cr, x, y);
 
-	cairo_set_line_width (cr, 2);
-	cairo_arc (cr, 7, 7, 6, 0, G_PI*2);
+	cairo_set_line_width (cr, MAX (1.0, floor (radius/3)));
+	cairo_arc (cr, ceil (cx), ceil (cy), floor (radius - 0.1), 0, G_PI*2);
 	cairo_set_source (cr, pt);
 	cairo_stroke (cr);
 	cairo_pattern_destroy (pt);
 
-	cairo_set_line_width (cr, 1);
+	cairo_set_line_width (cr, MAX (1.0, floor (radius/6)));
 
-	cairo_arc (cr, 7, 7, 5.5, 0, G_PI*2);
+	cairo_arc (cr, ceil (cx), ceil (cy), MAX (1.0, ceil (radius) - 1.5), 0, G_PI*2);
 
 	if (!widget->disabled)
 	{
@@ -1449,21 +1444,21 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 		if (inconsistent)
 		{
 			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
-			cairo_set_line_width (cr, 4);
+			cairo_set_line_width (cr, ceil (radius * 2 / 3));
 
-			cairo_move_to (cr, 5, 7);
-			cairo_line_to (cr, 9, 7);
+			cairo_move_to (cr, ceil (cx - radius/3.0), ceil (cy));
+			cairo_line_to (cr, ceil (cx + radius/3.0), ceil (cy));
 
 			ge_cairo_set_color (cr, dot);
 			cairo_stroke (cr);
 		}
 		else
 		{
-			cairo_arc (cr, 7, 7, 3, 0, G_PI*2);
+			cairo_arc (cr, ceil (cx), ceil (cy), floor (radius/2.0), 0, G_PI*2);
 			ge_cairo_set_color (cr, dot);
 			cairo_fill (cr);
 
-			cairo_arc (cr, 6, 6, 1, 0, G_PI*2);
+			cairo_arc (cr, floor (cx - radius/10.0), floor (cy - radius/10.0), floor (radius/6.0), 0, G_PI*2);
 			cairo_set_source_rgba (cr, highlight.r, highlight.g, highlight.b, 0.5);
 			cairo_fill (cr);
 		}
@@ -1554,6 +1549,26 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 	}
 }
 
+static void
+clearlooks_gummy_draw_icon_view_item (cairo_t                *cr,
+	                                  const ClearlooksColors *colors,
+	                                  const WidgetParameters *params,
+	                                  int x, int y, int width, int height)
+{
+	CairoColor color;
+	gfloat radius;
+
+	if (params->focus)
+		color = colors->base[params->state_type];
+	else
+		color = colors->base[GTK_STATE_ACTIVE];
+
+	radius = MIN (width / 2, params->radius);
+	radius = MIN (height / 2, radius);
+
+	clearlooks_draw_gummy_gradient (cr, x, y, width, height, &color, params->disabled, params->radius, CR_CORNER_ALL);
+}
+
 static void
 clearlooks_gummy_draw_focus (cairo_t                *cr,
                              const ClearlooksColors *colors,
@@ -1639,6 +1654,8 @@ clearlooks_gummy_draw_focus (cairo_t                *cr,
 			break;
 		case CL_FOCUS_SCALE:
 			break;
+		case CL_FOCUS_ICONVIEW:
+			break;
 		case CL_FOCUS_UNKNOWN:
 			/* Fallback to classic function, dots */
 			clearlooks_draw_focus (cr, colors, widget, focus, x, y, width, height);
@@ -1706,6 +1723,7 @@ clearlooks_register_style_gummy (ClearlooksStyleFunctions *functions, Clearlooks
 	functions->draw_statusbar          = clearlooks_gummy_draw_statusbar;
 	functions->draw_checkbox           = clearlooks_gummy_draw_checkbox;
 	functions->draw_radiobutton        = clearlooks_gummy_draw_radiobutton;
+	functions->draw_icon_view_item     = clearlooks_gummy_draw_icon_view_item;
 	functions->draw_focus              = clearlooks_gummy_draw_focus;
 
 	constants->topleft_highlight_shade = 1.3;
