@@ -52,7 +52,8 @@ typedef enum {
 	CL_FLAG_TOOLBARSTYLE       = 1 <<  7,
 	CL_FLAG_ANIMATION          = 1 <<  8,
 	CL_FLAG_RADIUS             = 1 <<  9,
-	CL_FLAG_HINT               = 1 <<  10
+	CL_FLAG_HINT               = 1 <<  10,
+	CL_FLAG_DISABLE_FOCUS      = 1 <<  11
 } ClearlooksRcFlags;
 
 
@@ -74,6 +75,7 @@ struct _ClearlooksRcStyle
 	gboolean animation;
 	double radius;
 	GQuark hint;
+	gboolean disable_focus;
 };
 
 struct _ClearlooksRcStyleClass
